@@ -17,6 +17,7 @@
  */
 
 #include "tclExtdInt.h"
+#include <stdint.h>
 
 /*
  * Keyed lists are stored as arrays recursively defined objects.  The data
@@ -144,25 +145,25 @@ static int
 TclX_KeylgetObjCmd (ClientData   clientData,
                     Tcl_Interp  *interp,
                     int	     objc,
-                    Tcl_Obj	    *CONST objv[]);
+                    Tcl_Obj	    *const objv[]);
 
 static int
 TclX_KeylsetObjCmd (ClientData   clientData,
                     Tcl_Interp  *interp,
                     int	     objc,
-                    Tcl_Obj	    *CONST objv[]);
+                    Tcl_Obj	    *const objv[]);
 
 static int 
 TclX_KeyldelObjCmd (ClientData   clientData,
                     Tcl_Interp  *interp,
                     int	     objc,
-                    Tcl_Obj	    *CONST objv[]);
+                    Tcl_Obj	    *const objv[]);
 
 static int 
 TclX_KeylkeysObjCmd (ClientData   clientData,
                      Tcl_Interp  *interp,
                      int	      objc,
-                     Tcl_Obj     *CONST objv[]);
+                     Tcl_Obj     *const objv[]);
 
 /*
  * Type definition.
@@ -246,7 +247,7 @@ ValidateKey (Tcl_Interp *interp, char *key, int keyLen)
  *-----------------------------------------------------------------------------
  */
 static keylIntObj_t *
-AllocKeyedListIntRep ()
+AllocKeyedListIntRep (void)
 {
     keylIntObj_t *keylIntPtr;
 
@@ -338,7 +339,7 @@ DeleteKeyedListEntry (keylIntObj_t *keylIntPtr, int entryIdx)
     if (keylIntPtr->hashTbl != NULL) {
 	Tcl_HashEntry *entryPtr;
 	Tcl_HashSearch search;
-	int nidx;
+	intptr_t nidx;
 
 	entryPtr = Tcl_FindHashEntry(keylIntPtr->hashTbl,
 		keylIntPtr->entries [entryIdx].key);
@@ -354,7 +355,7 @@ DeleteKeyedListEntry (keylIntObj_t *keylIntPtr, int entryIdx)
 	 */
 	for (entryPtr = Tcl_FirstHashEntry(keylIntPtr->hashTbl, &search);
 	     entryPtr != NULL; entryPtr = Tcl_NextHashEntry(&search)) {
-	    nidx = (int) Tcl_GetHashValue(entryPtr);
+	    nidx = (intptr_t) Tcl_GetHashValue(entryPtr);
 	    if (nidx > entryIdx) {
 		Tcl_SetHashValue(entryPtr, (ClientData) (uintptr_t) (nidx - 1));
 	    }
@@ -394,7 +395,8 @@ FindKeyedListEntry (keylIntObj_t *keylIntPtr,
                     char	    **nextSubKeyPtr)
 {
     char *keySeparPtr;
-    int keyLen, findIdx = -1;
+    int keyLen;
+    intptr_t findIdx = -1;
 
     keySeparPtr = strchr (key, '.');
     if (keySeparPtr != NULL) {
@@ -416,7 +418,7 @@ FindKeyedListEntry (keylIntObj_t *keylIntPtr,
 	}
 	entryPtr = Tcl_FindHashEntry(keylIntPtr->hashTbl, key);
 	if (entryPtr != NULL) {
-	    findIdx = (int) Tcl_GetHashValue(entryPtr);
+	    findIdx = (intptr_t) Tcl_GetHashValue(entryPtr);
 	}
 	if (keySeparPtr != NULL) {
 	    key[keyLen] = tmp;
@@ -672,7 +674,7 @@ UpdateStringOfKeyedList (Tcl_Obj *keylPtr)
  *-----------------------------------------------------------------------------
  */
 Tcl_Obj *
-TclX_NewKeyedListObj ()
+TclX_NewKeyedListObj (void)
 {
     Tcl_Obj *keylPtr = Tcl_NewObj ();
     keylIntObj_t *keylIntPtr = AllocKeyedListIntRep ();
@@ -1006,7 +1008,7 @@ static int
 TclX_KeylgetObjCmd (ClientData      clientData,
                     Tcl_Interp     *interp,
                     int             objc,
-                    Tcl_Obj *CONST objv[])
+                    Tcl_Obj *const objv[])
 {
     Tcl_Obj *keylPtr, *valuePtr;
     char *key;
@@ -1084,7 +1086,7 @@ static int
 TclX_KeylsetObjCmd (ClientData     clientData,
                     Tcl_Interp    *interp,
                     int            objc,
-                    Tcl_Obj *CONST objv[])
+                    Tcl_Obj *const objv[])
 {
     Tcl_Obj *keylVarPtr, *newVarObj;
     char *key;
@@ -1143,7 +1145,7 @@ static int
 TclX_KeyldelObjCmd (ClientData  clientData,
                     Tcl_Interp *interp,
                     int         objc,
-                    Tcl_Obj    *CONST objv[])
+                    Tcl_Obj    *const objv[])
 {
     Tcl_Obj *keylVarPtr, *keylPtr;
     char *key;
@@ -1204,7 +1206,7 @@ static int
 TclX_KeylkeysObjCmd (ClientData   clientData,
                      Tcl_Interp  *interp,
                      int          objc,
-                     Tcl_Obj     *CONST objv[])
+                     Tcl_Obj     *const objv[])
 {
     Tcl_Obj *keylPtr, *listObjPtr;
     char *key;
